@@ -1,8 +1,9 @@
 """HDFS Utilities"""
 
+from typing import Optional
 import logging
-import pyarrow
 
+import pyarrow
 from pyarrow.filesystem import FileSystem
 
 
@@ -60,10 +61,11 @@ class HDFSFile:
         Write / read mode. Supported: "r", "rb" (default), "w", "wb".
     """
 
-    def __init__(self, filesystem: FileSystem, path: str, mode: str = "rb"):
+    def __init__(self, filesystem: FileSystem, path: str, mode: str = "rb", encoding: Optional[str] = "utf-8"):
         self.filesystem = filesystem
         self.path = path
         self.mode = mode
+        self.encoding = None if "b" in mode else encoding
         self._file = filesystem.open(self.path, mode={"r": "rb", "w": "wb"}.get(mode, mode))
 
     def __iter__(self):
@@ -80,17 +82,21 @@ class HDFSFile:
         # Expose self._file methods and attributes (mimic inheritance)
         return getattr(self._file, name)
 
-    def write(self, data):
+    def write(self, data, *args, **kwargs):
         if self.mode == "w":
-            self._file.write(data.encode())
+            self._file.write(data.encode(encoding=self.encoding), *args, **kwargs)
+        elif self.mode == "wb":
+            self._file.write(data, *args, **kwargs)
         else:
-            self._file.write(data)
+            raise ValueError(f"Mode {self.mode} unkown (must be 'w' or 'wb').")
 
-    def read(self):
+    def read(self, *args, **kwargs):
         if self.mode == "r":
-            return self._file.read().decode()
+            return self._file.read(*args, **kwargs).decode(encoding=self.encoding)
+        elif self.mode == "rb":
+            return self._file.read(*args, **kwargs)
         else:
-            return self._file.read()
+            raise ValueError(f"Mode {self.mode} unkown (must be 'r' or 'rb')")
 
     def readlines(self):
         return self.read().split("\n" if self.mode == "r" else b"\n")
